From 339e1bfc3b5e9c02542473c3185aa69444c83432 Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <daniel@yesql.se>
Date: Fri, 16 Feb 2018 20:30:27 +0100
Subject: [PATCH] Only allow doc issues from supported versions

Fixes for unsupported documentation won't be committed, so rather
than accept a documentation fix instead redirect the user to the
current version of the page and ask for a fix there unless the
issue has been addressed already.
---
 templates/docs/docspage.html | 20 +++++++++++++++-----
 1 file changed, 15 insertions(+), 5 deletions(-)

diff --git a/templates/docs/docspage.html b/templates/docs/docspage.html
index ca2bd17..fb75b64 100644
--- a/templates/docs/docspage.html
+++ b/templates/docs/docspage.html
@@ -92,11 +92,21 @@ This page in other versions:
 
 <h2>Submit correction</h2>
 <p>
-If you see anything in the documentation that is not correct, does not match
-your experience with the particular feature or requires further clarification,
-please use
-<a href="/account/comments/new/{{page.version.numtree|default:"devel"}}/{{page.file}}/" rel="nofollow">this form</a>
-to report a documentation issue.
+{%for ver in unsupported_versions%}
+	{%if ver.version == page.version %}
+		If you see anything in the documentation that is not correct, does not match
+		your experience with the particular feature or requires further clarification,
+		please check if this has been fixed in the
+		<a href="/docs/current/static/{{page.file}}/">current version</a> of the documentation. If
+		not, please report a documentation issue using the form on that page.
+	{% else %}
+		If you see anything in the documentation that is not correct, does not match
+		your experience with the particular feature or requires further clarification,
+		please use
+		<a href="/account/comments/new/{{page.version.numtree|default:"devel"}}/{{page.file}}/" rel="nofollow">this form</a>
+		to report a documentation issue.
+	{% endif %}
+{%endfor%}
 </p>
 </div>
 
-- 
2.14.1.145.gb3622a4ee

